==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgconnect.h <==
/***************************************************************************
                          dlgconnect.h  -  Connect dialog
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : t Jul 23 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGCONNECT_H
#define DLGCONNECT_H

#include <qwidget.h>
#include <kdialogbase.h>

class KListView;
class KPushButton;
class QStringList;
class QListViewItem;
class QCheckBox;

/**
Connect dialog. Shown and handled by cConnection.
  *@author Tomas Mecir
  */

class dlgConnect : public KDialogBase {
Q_OBJECT
public: 
  dlgConnect (QWidget *parent=0, const char *name=0);
  ~dlgConnect ();

  QString selName ();
  bool sendNothing ();
  void updateList ();
  void setSelectedItem (const QString &name);
  bool isOffLine ();
signals:
  void addPressed ();
  void modifyPressed ();
  void deletePressed ();
  void duplicatePressed ();
protected:
  KPushButton *addButton, *modifyButton, *deleteButton, *duplicateButton;
  KListView *lw;
  QCheckBox *chkSendNothing;
  QCheckBox *chkOffline;
  
  QStringList *plist;

  bool firstUpdate;

  static QString lastSelected;
protected slots:
  void selectionChanged ();
  void doubleClicked (QListViewItem *);
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgconnect.h <==
/***************************************************************************
                          dlgconnect.h  -  Connect dialog
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : t Jul 23 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGCONNECT_H
#define DLGCONNECT_H

#include <qwidget.h>
#include <kdialogbase.h>

class KListView;
class KPushButton;
class QStringList;
class QListViewItem;
class QCheckBox;

/**
Connect dialog. Shown and handled by cConnection.
  *@author Tomas Mecir
  */

class dlgConnect : public KDialogBase {
Q_OBJECT
public: 
  dlgConnect (QWidget *parent=0, const char *name=0);
  ~dlgConnect ();

  QString selName ();
  bool sendNothing ();
  void updateList ();
  void setSelectedItem (const QString &name);
  bool isOffLine ();
signals:
  void addPressed ();
  void modifyPressed ();
  void deletePressed ();
  void duplicatePressed ();
protected:
  KPushButton *addButton, *modifyButton, *deleteButton, *duplicateButton;
  KListView *lw;
  QCheckBox *chkSendNothing;
  QCheckBox *chkOffline;
  
  QStringList *plist;

  bool firstUpdate;

  static QString lastSelected;
protected slots:
  void selectionChanged ();
  void doubleClicked (QListViewItem *);
};

#endif
